import React, { useState } from "react";
import DatePicker from "react-datepicker";
import "react-datepicker/dist/react-datepicker.css";
import useLanguage from "../../hooks/useLanguage";

function CartAddress({
  deliveryType,
  setDeliveryType,
  address,
  setAddress,
  date,
  setDate,
  mapHandler,
}) {
  const language = useLanguage();
  const [locationTooltip, setLocationTooltip] = useState(true);
  const toolTipHandler = () => {
    setLocationTooltip(true);
    mapHandler();
  };
  return (
    <div className="sm:p-7   gap-7 grid-cols-2 grid">
      <div className=" flex flex-col col-span-2 xl:col-span-1 gap-5">
        <div
          onClick={() => {
            setDeliveryType("delivery");
          }}
          className={` border-2 ${
            deliveryType === "delivery" ? "border-primary-200" : ""
          }  rounded-md py-4 pr-7 pl-4 flex`}
        >
          <label className="flex h-fit items-center gap-2" htmlFor="delivery">
            <div>
              <h1 className=" text-2xl font-bold text-dark-300  notranslate">
                {language["Delivery Type"]}
              </h1>
              <p className=" text-lg text-dark-200">
                {
                  language[
                    "Delivery costs are calculated after placing your order."
                  ]
                }
              </p>
            </div>
            <div className="min-h-6 min-w-6 h-6 w-6 rounded-full overflow-hidden relative border-dark-200 bg-[#BDBDBD] justify-center items-center flex">
              <img src="./img/check.svg" alt="no" className=" absolute " />
              <input
                type="checkbox"
                id="delivery"
                checked={deliveryType === "delivery"}
                className=" checkbox w-6 h-6 rounded-full z-50 accent-primary-200 border-dark-200 bg-transparent outline-dark-200 border-opacity-30 checked:bg-primary-200 checked:hover:bg-primary-200 text-primary-200 "
              />
            </div>
          </label>
        </div>
        <div
          onClick={() => {
            setDeliveryType("pickup");
          }}
          className={` border-2 ${
            deliveryType === "pickup" ? "border-primary-200" : ""
          }  rounded-md py-4 pr-7 pl-4 flex`}
        >
          <label className="flex h-fit items-center gap-2" htmlFor="pickup">
            <div>
              <h1 className=" text-2xl font-bold text-dark-300 notranslate">
                {language["Pickup"]}
              </h1>
              <p className=" text-lg text-dark-200">
                {
                  language[
                    "Pickup details will be confirmed after registration."
                  ]
                }
              </p>
            </div>
            <div
              className={`min-h-6 min-w-6 h-6 w-6 rounded-full overflow-hidden relative border-dark-200 bg-[#BDBDBD] justify-center items-center flex`}
            >
              <img src="./img/check.svg" alt="no" className=" absolute " />
              <input
                type="checkbox"
                id="pickup"
                checked={deliveryType === "pickup"}
                className=" checkbox w-full h-6 rounded-full z-50 accent-primary-200 border-dark-200 bg-transparent outline-dark-200 border-opacity-30 checked:bg-primary-200 checked:hover:bg-primary-200 text-primary-200 "
              />
            </div>
          </label>
        </div>
      </div>
      {/* text input  */}
      <div className=" p-7 col-span-2 xl:col-span-1 border border-primary-100 bg-primary-100 rounded-md bg-opacity-80">
        <div className="flex flex-col gap-2">
          <label className=" text-sm font-medium text-dark-300">
            <p> {location["Set your Location"]}</p>
          </label>
          <div className="relative h-fit flex items-center ">
            <svg
              onClick={toolTipHandler}
              className=" absolute left-4 cursor-pointer"
              xmlns="http://www.w3.org/2000/svg"
              width="18"
              height="21"
              viewBox="0 0 18 21"
              fill="none"
            >
              <path
                d="M12.419 13.5314C14.5984 10.1117 14.3244 10.5383 14.3872 10.4492C15.1806 9.33004 15.6 8.01288 15.6 6.64C15.6 2.9992 12.6456 0 9 0C5.36632 0 2.4 2.99328 2.4 6.64C2.4 8.012 2.82816 9.36364 3.6476 10.4978L5.58088 13.5314C3.51388 13.8491 0 14.7957 0 16.88C0 17.6398 0.49592 18.7226 2.85848 19.5664C4.50816 20.1555 6.68924 20.48 9 20.48C13.321 20.48 18 19.2611 18 16.88C18 14.7953 14.4902 13.8497 12.419 13.5314ZM4.64996 9.8378C4.64336 9.82748 4.63648 9.8174 4.62928 9.80748C3.9474 8.8694 3.6 7.75764 3.6 6.64C3.6 3.63928 6.01624 1.2 9 1.2C11.9776 1.2 14.4 3.64036 14.4 6.64C14.4 7.75944 14.0592 8.83348 13.4142 9.74684C13.3564 9.82308 13.6579 9.3546 9 16.6636L4.64996 9.8378ZM9 19.28C4.28024 19.28 1.2 17.8927 1.2 16.88C1.2 16.1994 2.78272 15.0802 6.28992 14.644L8.494 18.1025C8.60416 18.2754 8.79496 18.38 8.99996 18.38C9.20496 18.38 9.3958 18.2753 9.50592 18.1025L11.71 14.644C15.2172 15.0802 16.8 16.1994 16.8 16.88C16.8 17.8841 13.7475 19.28 9 19.28Z"
                fill="#001C31"
              />
              <path
                d="M9 3.64014C7.3458 3.64014 6 4.98594 6 6.64014C6 8.29434 7.3458 9.64014 9 9.64014C10.6542 9.64014 12 8.29434 12 6.64014C12 4.98594 10.6542 3.64014 9 3.64014ZM9 8.44014C8.00748 8.44014 7.2 7.63266 7.2 6.64014C7.2 5.64762 8.00748 4.84014 9 4.84014C9.99252 4.84014 10.8 5.64762 10.8 6.64014C10.8 7.63266 9.99252 8.44014 9 8.44014Z"
                fill="#001C31"
              />
            </svg>
            {locationTooltip && (
              <div className="absolute left-0 -top-8 before:absolute before:left-4 before:-bottom-4 before:border-[10px] before:border-t-black before:border-l-transparent before:border-r-transparent before:border-b-transparent   before:content-[''] before:block  bg-black text-white px-2 py-1">
                <div className="flex space-x-5 items-center">
                  <span>Choose your location</span>
                  <button
                    type="button"
                    onClick={() => setLocationTooltip(false)}
                  >
                    <svg
                      className="w-5 h-5"
                      xmlns="http://www.w3.org/2000/svg"
                      viewBox="0 0 24 24"
                      fill="currentColor"
                    >
                      <path d="M11.9997 10.5865L16.9495 5.63672L18.3637 7.05093L13.4139 12.0007L18.3637 16.9504L16.9495 18.3646L11.9997 13.4149L7.04996 18.3646L5.63574 16.9504L10.5855 12.0007L5.63574 7.05093L7.04996 5.63672L11.9997 10.5865Z"></path>
                    </svg>
                  </button>
                </div>
              </div>
            )}

            <input
              type="text"
              name="location"
              placeholder="Type your address"
              value={address}
              onChange={(e) => setAddress(e.target.value)}
              className=" pl-11 w-full py-3 border-none outline-none focus:border-none focus:outline-none rounded"
            />
          </div>
        </div>
        <div className="flex flex-col gap-2 mt-6">
          <label className="notranslate">{language["Delivery Date"]}</label>
          <div className="relative h-fit flex items-center w-full bg-white rounded ">
            <svg
              className=" absolute left-4 "
              xmlns="http://www.w3.org/2000/svg"
              width="18"
              height="18"
              viewBox="0 0 18 18"
              fill="none"
            >
              <path
                d="M13.5703 8.08594C13.9586 8.08594 14.2734 7.77114 14.2734 7.38281C14.2734 6.99449 13.9586 6.67969 13.5703 6.67969C13.182 6.67969 12.8672 6.99449 12.8672 7.38281C12.8672 7.77114 13.182 8.08594 13.5703 8.08594Z"
                fill="#001C31"
              />
              <path
                d="M15.1875 1.40625H14.2734V0.703125C14.2734 0.314789 13.9586 0 13.5703 0C13.182 0 12.8672 0.314789 12.8672 0.703125V1.40625H9.66797V0.703125C9.66797 0.314789 9.35318 0 8.96484 0C8.57651 0 8.26172 0.314789 8.26172 0.703125V1.40625H5.09766V0.703125C5.09766 0.314789 4.78287 0 4.39453 0C4.0062 0 3.69141 0.314789 3.69141 0.703125V1.40625H2.8125C1.26169 1.40625 0 2.66794 0 4.21875V15.1875C0 16.7383 1.26169 18 2.8125 18H8.19141C8.57974 18 8.89453 17.6852 8.89453 17.2969C8.89453 16.9085 8.57974 16.5938 8.19141 16.5938H2.8125C2.03709 16.5938 1.40625 15.9629 1.40625 15.1875V4.21875C1.40625 3.44334 2.03709 2.8125 2.8125 2.8125H3.69141V3.51562C3.69141 3.90396 4.0062 4.21875 4.39453 4.21875C4.78287 4.21875 5.09766 3.90396 5.09766 3.51562V2.8125H8.26172V3.51562C8.26172 3.90396 8.57651 4.21875 8.96484 4.21875C9.35318 4.21875 9.66797 3.90396 9.66797 3.51562V2.8125H12.8672V3.51562C12.8672 3.90396 13.182 4.21875 13.5703 4.21875C13.9586 4.21875 14.2734 3.90396 14.2734 3.51562V2.8125H15.1875C15.9629 2.8125 16.5938 3.44334 16.5938 4.21875V8.22656C16.5938 8.6149 16.9085 8.92969 17.2969 8.92969C17.6852 8.92969 18 8.6149 18 8.22656V4.21875C18 2.66794 16.7383 1.40625 15.1875 1.40625Z"
                fill="#001C31"
              />
              <path
                d="M13.7461 9.49219C11.4005 9.49219 9.49219 11.4005 9.49219 13.7461C9.49219 16.0917 11.4005 18 13.7461 18C16.0917 18 18 16.0917 18 13.7461C18 11.4005 16.0917 9.49219 13.7461 9.49219ZM13.7461 16.5938C12.1759 16.5938 10.8984 15.3163 10.8984 13.7461C10.8984 12.1759 12.1759 10.8984 13.7461 10.8984C15.3163 10.8984 16.5938 12.1759 16.5938 13.7461C16.5938 15.3163 15.3163 16.5938 13.7461 16.5938Z"
                fill="#001C31"
              />
              <path
                d="M14.7656 13.043H14.4492V12.3047C14.4492 11.9164 14.1344 11.6016 13.7461 11.6016C13.3578 11.6016 13.043 11.9164 13.043 12.3047V13.7461C13.043 14.1344 13.3578 14.4492 13.7461 14.4492H14.7656C15.154 14.4492 15.4688 14.1344 15.4688 13.7461C15.4688 13.3578 15.154 13.043 14.7656 13.043Z"
                fill="#001C31"
              />
              <path
                d="M10.5117 8.08594C10.9 8.08594 11.2148 7.77114 11.2148 7.38281C11.2148 6.99449 10.9 6.67969 10.5117 6.67969C10.1234 6.67969 9.80859 6.99449 9.80859 7.38281C9.80859 7.77114 10.1234 8.08594 10.5117 8.08594Z"
                fill="#001C31"
              />
              <path
                d="M7.45312 11.1445C7.84145 11.1445 8.15625 10.8297 8.15625 10.4414C8.15625 10.0531 7.84145 9.73828 7.45312 9.73828C7.0648 9.73828 6.75 10.0531 6.75 10.4414C6.75 10.8297 7.0648 11.1445 7.45312 11.1445Z"
                fill="#001C31"
              />
              <path
                d="M4.39453 8.08594C4.78286 8.08594 5.09766 7.77114 5.09766 7.38281C5.09766 6.99449 4.78286 6.67969 4.39453 6.67969C4.00621 6.67969 3.69141 6.99449 3.69141 7.38281C3.69141 7.77114 4.00621 8.08594 4.39453 8.08594Z"
                fill="#001C31"
              />
              <path
                d="M4.39453 11.1445C4.78286 11.1445 5.09766 10.8297 5.09766 10.4414C5.09766 10.0531 4.78286 9.73828 4.39453 9.73828C4.00621 9.73828 3.69141 10.0531 3.69141 10.4414C3.69141 10.8297 4.00621 11.1445 4.39453 11.1445Z"
                fill="#001C31"
              />
              <path
                d="M4.39453 14.2031C4.78286 14.2031 5.09766 13.8883 5.09766 13.5C5.09766 13.1117 4.78286 12.7969 4.39453 12.7969C4.00621 12.7969 3.69141 13.1117 3.69141 13.5C3.69141 13.8883 4.00621 14.2031 4.39453 14.2031Z"
                fill="#001C31"
              />
              <path
                d="M7.45312 14.2031C7.84145 14.2031 8.15625 13.8883 8.15625 13.5C8.15625 13.1117 7.84145 12.7969 7.45312 12.7969C7.0648 12.7969 6.75 13.1117 6.75 13.5C6.75 13.8883 7.0648 14.2031 7.45312 14.2031Z"
                fill="#001C31"
              />
              <path
                d="M7.45312 8.08594C7.84145 8.08594 8.15625 7.77114 8.15625 7.38281C8.15625 6.99449 7.84145 6.67969 7.45312 6.67969C7.0648 6.67969 6.75 6.99449 6.75 7.38281C6.75 7.77114 7.0648 8.08594 7.45312 8.08594Z"
                fill="#001C31"
              />
            </svg>
            <DatePicker selected={date} onChange={(date) => setDate(date)} />
          </div>
        </div>
      </div>
    </div>
  );
}

export default CartAddress;
